# = Class: denyhosts
#
# This class installs/configures/manages denyhosts.
#
# == Parameters
#
# [*purge_deny*]
#   Remove blocked hosts older than this on a purge. Specified in denyhosts
#   date/time format. Defaults to '4w'.
# [*purge_threshold*]
#   Maximum times a host will be purged. Defaults to 0.
# [*block_service*]
#   Service to monitor. Defaults to 'sshd'.
# [*deny_threshold*]
#   Block a host after this many failed login attempts. Defaults to 3.
# [*deny_threshold_strict*]
#   Block a host after this many failed login attempts to the root
#   account or other restricted accounts. Defaults to 1.
# [*admin_email*]
#   Administrator email. Denyhosts reports are sent to this email.
#   Defaults to 'root'.
# [*smtp_host*]
#   SMTP server. Defaults to 'localhost'.
# [*smtp_port*]
#   SMTP port. Defaults to 25.
# [*smtp_from*]
#   SMTP source address. Defaults to nobody@localhost.
# [*smtp_subject*]
#   SMTP subject field.
# [*age_reset*]
#   How long to block a host after a failed login attempt. Specified in
#   denyhosts date/time format. Defaults to '5d'.
# [*age_reset_strict*]
#   Similar to $age_reset but for root and restricted accounts.
#   Defaults to '25d'.
# [*reset_on_success*]
#   Reset the failed login count for a host after a successful login.
#   Defaults to false.
#
# == Authors
#
# Alexandru Barbur <alex@barbur.net>
#
class denyhosts
(
    $enable = true,
    $purge_deny = '4w',
    $purge_threshold = 0,
    $block_service = 'sshd',
    $deny_threshold = 3,
    $deny_threshold_strict = 1,
    $admin_email = 'root',
    $smtp_host = 'localhost',
    $smtp_port = 25,
    $smtp_from = 'DenyHosts <nobody@localhost>',
    $smtp_subject = "DenyHosts Report from $::fqdn",
    $age_reset = '5d',
    $age_reset_strict = '25d',
    $reset_on_success = false
)
{
    # platform specific settings
    case $::osfamily {
        redhat: {
            $secure_log = '/var/log/secure'
            $lock_file = '/var/lock/subsys/denyhosts'
        }
        debian: {
            $secure_log = '/var/log/auth.log'
            $lock_file = '/var/run/denyhosts.pid'
        }
        default: {
            fail("Module ${module_name} is not supported on ${::osfamily}.")
        }
    }

    # validate parameters	
    validate_bool($enable)
    validate_bool($reset_on_success)

    # package
    package {'denyhosts':
        ensure  => installed
    }

    # config file
    file {'denyhosts.conf':
        ensure  => file,
        path    => '/etc/denyhosts.conf',
        owner   => 'root',
        group   => 'root',
        mode    => '0600',
        require => Package['denyhosts'],
        content => template('denyhosts/denyhosts.conf.erb')
    }

	# whitelist
	concat {'denyhosts.whitelist':
		path    => '/var/lib/denyhosts/allowed-hosts',
		owner   => 'root',
		group   => 'root',
		mode    => '0644',
		require => Package['denyhosts']
	}

	concat::fragment {'denyhosts.whitelist-header':
		target  => 'denyhosts.whitelist',
		order   => '01',
		content => "# This file is managed by puppet. Do not modify locally.\n"
	}

	denyhosts::whitelist {'localhost':
		hosts => ['127.0.0.1']
	}

    # service
    service {'denyhosts':
        ensure    => $enable,
        enable    => $enable,
		require   => Package['denyhosts'],
        subscribe => [File['denyhosts.conf'], Concat['denyhosts.whitelist']]
    }
}
